convert_alias_to_entrez: Convert list of gene aliases to entrez ids if 1:many mapping...

convert_alias_to_entrezR Documentation

Convert list of gene aliases to entrez ids if 1:many mapping occurs pick the first entrez id listed in the AnnotationDbi organism database map

Description

Convert list of gene aliases to entrez ids if 1:many mapping occurs pick the first entrez id listed in the AnnotationDbi organism database map

Usage

convert_alias_to_entrez(list, id_type = "alias", organism = "hsapiens")

karltayeb/gseareg documentation built on June 9, 2025, 1:40 a.m.